look_at_quat

Function look_at_quat 

pub fn look_at_quat(eye: DVec3, center: DVec3, up: DVec3) -> DQuat
Returns a DQuat view rotation from eye, focal point, and up.

Transforms left-handed world space points into left-handed Y-up view space.

Panics

Will panic if up is not normalized when glam_assert is enabled.